package com.aucma.dms.controller;

//import com.hw.common.core.utils.poi.ExcelUtil;
//import com.hw.common.core.web.controller.BaseController;
//import com.hw.common.core.web.domain.AjaxResult;
//import com.hw.common.core.web.page.TableDataInfo;
//import com.hw.common.log.annotation.Log;
//import com.hw.common.log.enums.BusinessType;
//import com.hw.common.security.annotation.RequiresPermissions;
//import com.aucma.dms.domain.DmsKnowledgeLube;
//import com.aucma.dms.service.IDmsKnowledgeLubeService;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsKnowledgeLube;
import com.aucma.dms.service.IDmsKnowledgeLubeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 润滑知识库Controller
 * 
 * @author caoql
 * @date 2024-02-26
 */
@RestController
@RequestMapping("/dms/knowledgeLube")
public class DmsKnowledgeLubeController extends BaseController
{
    @Autowired
    private IDmsKnowledgeLubeService dmsKnowledgeLubeService;

    /**
     * 查询润滑知识库列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsKnowledgeLube dmsKnowledgeLube)
    {
        startPage();
        List<DmsKnowledgeLube> list = dmsKnowledgeLubeService.selectDmsKnowledgeLubeList(dmsKnowledgeLube);
        return getDataTable(list);
    }

    /**
     * 导出润滑知识库列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:export')" )
    //@Log(title = "润滑知识库", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsKnowledgeLube dmsKnowledgeLube)
    {
        List<DmsKnowledgeLube> list = dmsKnowledgeLubeService.selectDmsKnowledgeLubeList(dmsKnowledgeLube);
        ExcelUtil<DmsKnowledgeLube> util = new ExcelUtil<DmsKnowledgeLube>(DmsKnowledgeLube.class);
        util.exportExcel(response, list, "润滑知识库数据");
    }

    /**
     * 获取润滑知识库详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:query')" )
    @GetMapping(value = "/{knowledgeLubeId}")
    public AjaxResult getInfo(@PathVariable("knowledgeLubeId") Long knowledgeLubeId)
    {
        return success(dmsKnowledgeLubeService.selectDmsKnowledgeLubeByKnowledgeLubeId(knowledgeLubeId));
    }

    /**
     * 新增润滑知识库
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:add')" )
    //@Log(title = "润滑知识库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsKnowledgeLube dmsKnowledgeLube)
    {
        return toAjax(dmsKnowledgeLubeService.insertDmsKnowledgeLube(dmsKnowledgeLube));
    }

    /**
     * 修改润滑知识库
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:edit')" )
    //@Log(title = "润滑知识库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsKnowledgeLube dmsKnowledgeLube)
    {
        return toAjax(dmsKnowledgeLubeService.updateDmsKnowledgeLube(dmsKnowledgeLube));
    }

    /**
     * 删除润滑知识库
     */
    //@PreAuthorize("@ss.hasPermi('dms:knowledgeLube:remove')" )
    //@Log(title = "润滑知识库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{knowledgeLubeIds}")
    public AjaxResult remove(@PathVariable Long[] knowledgeLubeIds)
    {
        return toAjax(dmsKnowledgeLubeService.deleteDmsKnowledgeLubeByKnowledgeLubeIds(knowledgeLubeIds));
    }
}
